@@ -1,7 +1,7 @@
 package Mail::Milter::Authentication::Handler;
 use strict;
 use warnings;
-use version; our $VERSION = version->declare('v1.1.6');
+use version; our $VERSION = version->declare('v1.1.7');
 
 use Digest::MD5 qw{ md5_hex };
 use English qw{ -no_match_vars };
@@ -1338,8 +1338,8 @@ sub header_sort {
         foreach my $name ( @{$config->{'load_handlers'}} ) {
             if ( lc $name eq lc $handler_a ) {
                 my $handler = $self->get_handler($name);
-                if ( $handler->can( 'header_sort' ) ) {
-                    return $handler->header_sort( $sa, $sb );
+                if ( $handler->can( 'handler_header_sort' ) ) {
+                    return $handler->handler_header_sort( $sa, $sb );
                 }
             }
         }
