@@ -144,13 +144,22 @@ sub test_metrics {
         }
         else {
             fail( 'Metrics data does not exist' );
-            if ( $ENV{'WRITE_METRICS'} ) {
-                open my $OutF, '>', $expected;
-                $j->pretty();
-                $j->canonical();
-                print $OutF $j->encode( $metrics );
-                close $OutF;
+        }
+
+        if ( $ENV{'WRITE_METRICS'} ) {
+            foreach my $key ( sort keys %$metrics ) {
+                if ( $key =~ /seconds_total/ ) {
+                    $metrics->{ $key } = 123456 if $metrics->{ $key } > 0;
+                }
+                elsif ( $key =~ /microseconds_sum/ ) {
+                    $metrics->{ $key } = 123456 if $metrics->{ $key } > 0;
+                }
             }
+            open my $OutF, '>', $expected;
+            $j->pretty();
+            $j->canonical();
+            print $OutF $j->encode( $metrics );
+            close $OutF;
         }
 
     };
