@@ -175,6 +175,17 @@ sub run_milter_processing {
         'to'     => 'marc@fastmail.com',
     });
 
+    milter_process({
+        'desc'   => 'Good message CNAME',
+        'prefix' => 'config/normal',
+        'source' => 'google_apps_good.eml',
+        'dest'   => 'google_apps_good_cn.eml',
+        'ip'     => '74.125.82.172',
+        'name'   => 'mail-we0-f172.google.com',
+        'from'   => 'marc@marcbradshaw.net',
+        'to'     => 'marc@fastmail.com',
+    });
+
     milter_process({
         'desc'   => 'SPF Fail',
         'prefix' => 'config/normal',
@@ -285,6 +296,28 @@ sub run_milter_processing {
         'to'     => 'marc@fastmail.com',
     });
 
+    milter_process({
+        'desc'   => 'DMARC Multi',
+        'prefix' => 'config/normal',
+        'source' => 'dmarc_multi.eml',
+        'dest'   => 'dmarc_multi.eml',
+        'ip'     => '123.123.123.123',
+        'name'   => 'bad.name.google.com',
+        'from'   => 'test@goestheweasel.com',
+        'to'     => 'marc@fastmail.com',
+    });
+
+    milter_process({
+        'desc'   => 'DMARC Multi',
+        'prefix' => 'config/normal',
+        'source' => 'dmarc_multi.eml',
+        'dest'   => 'dmarc_multi_2.eml',
+        'ip'     => '123.123.123.123',
+        'name'   => 'bad.name.google.com',
+        'from'   => 'test@goestheweasel.com, test@marcbradshaw.net',
+        'to'     => 'marc@fastmail.com',
+    });
+
     test_metrics( 'data/metrics/milter_1.json' );
 
     stop_milter();
@@ -503,6 +536,17 @@ sub run_smtp_processing {
         'to'     => 'marc@fastmail.com',
     });
 
+    smtp_process({
+        'desc'   => 'Good message CNAME',
+        'prefix' => 'config/normal.smtp',
+        'source' => 'google_apps_good.eml',
+        'dest'   => 'google_apps_good_cn.smtp.eml',
+        'ip'     => '74.125.82.172',
+        'name'   => 'mail-we0-f172.google.com',
+        'from'   => 'marc@marcbradshaw.net',
+        'to'     => 'marc@fastmail.com',
+    });
+
     smtp_process({
         'desc'   => 'SPF Fail',
         'prefix' => 'config/normal.smtp',
